# hugdatafast
The elegant integration of huggingface/nlp and fastai, and some handy data transformation for huggingface/nlp.

🎓 **Documentation** : https://hugdatafast.readthedocs.io/en/latest/

# Install
`pip install hugdatafast`

# Furture Plan
- I would like to merge this library to fastai and huggingface/nlp respectively. But I may have no time for it. You're welcome to help the library merged to the two.
- The implemenatation of `ConcatTransform` works but might be too complexed to extend, so I may discuss with huggingface to see how to improve it, if I have time.
- Currently, it is designed to work with the dataset part of huggingface/nlp, I may also integrate metric part of it.